@@ -10,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 	/* ------------------------------------------------------------
@@ -348,16 +348,16 @@ int drawSmeter(int xpos, int ypos, int yheight, float testvalue)
 	    break;
 	case 5:
 	    if (use_rxvt == 0)
-		attron(COLOR_PAIR(COLOR_GREEN) | A_BOLD | A_STANDOUT);
+		attron(COLOR_PAIR(C_HEADER) | A_BOLD | A_STANDOUT);
 	    else
-		attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+		attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
 	    mvprintw(ypos + i, xpos, ">   <");
 
 	    if (use_rxvt == 0)
-		attron(COLOR_PAIR(COLOR_CYAN) | A_BOLD | A_STANDOUT);
+		attron(COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
 	    else
-		attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+		attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 	}
     }
 
@@ -400,9 +400,9 @@ int panscan(void)
     while (1) {
 	key = 0;
 	if (use_rxvt == 0)
-	    attron(COLOR_PAIR(COLOR_CYAN) | A_BOLD | A_STANDOUT);
+	    attron(COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
 	else
-	    attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+	    attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
 	for (j = 0; j <= 24; j++)
 	    mvprintw(j, 0,
@@ -509,9 +509,9 @@ int nbscan(void)
     while (1) {
 	key = 0;
 	if (use_rxvt == 0)
-	    attron(COLOR_PAIR(COLOR_CYAN) | A_BOLD | A_STANDOUT);
+	    attron(COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
 	else
-	    attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+	    attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
 	for (j = 0; j <= 24; j++)	// wipe the screen
 	    mvprintw(j, 0,
@@ -603,9 +603,9 @@ void scanmenu(void)
     int j;
 
     if (use_rxvt == 0)
-	attron(COLOR_PAIR(COLOR_CYAN) | A_BOLD | A_STANDOUT);
+	attron(COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
     else
-	attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+	attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
     for (j = 0; j <= 24; j++)
 	mvprintw(j, 0,
@@ -680,9 +680,9 @@ void recordmenue(void)
     int j;
 
     if (use_rxvt == 0)
-	attron(COLOR_PAIR(COLOR_CYAN) | A_BOLD | A_STANDOUT);
+	attron(COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
     else
-	attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+	attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
     for (j = 0; j <= 24; j++)
 	mvprintw(j, 0,
