@@ -10,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
     /* ------------------------------------------------------------
@@ -45,7 +45,7 @@ void calledit(void)
     while ((i != 27) && (b <= strlen(hiscall))) {
 
 	attroff(A_STANDOUT);
-	attron(COLOR_PAIR(COLOR_GREEN));
+	attron(COLOR_PAIR(C_HEADER));
 
 	mvprintw(12, 29, "            ");
 	mvprintw(12, 29, hiscall);
@@ -179,7 +179,7 @@ void calledit(void)
     }
 
     attroff(A_STANDOUT);
-    attron(COLOR_PAIR(COLOR_GREEN));
+    attron(COLOR_PAIR(C_HEADER));
 
     mvprintw(12, 29, hiscall);
     mvprintw(12, 29, "            ");
@@ -198,7 +198,7 @@ int insert_char(int curposition)
     int ichr = 0;
 
     attroff(A_STANDOUT);
-    attron(COLOR_PAIR(COLOR_GREEN));
+    attron(COLOR_PAIR(C_HEADER));
 
     call1[0] = '\0';
     call2[0] = '\0';
@@ -238,7 +238,7 @@ int insert_char(int curposition)
 	    break;
 
 	attroff(A_STANDOUT);
-	attron(COLOR_PAIR(COLOR_GREEN));
+	attron(COLOR_PAIR(C_HEADER));
 
 	mvprintw(12, 29, hiscall);
 	curposition++;
