@@ -10,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 	/* ------------------------------------------------------------
@@ -25,12 +25,11 @@
 
 #include "globalvars.h"
 #include "clear_display.h"
+#include "cw_utils.h"
 
 void clear_display(void)
 {
     extern int use_rxvt;
-    extern char speedstr[];
-    extern int speed;
     extern char mode[];
     extern int cqdelay;
     extern char headerline[];
@@ -59,20 +58,20 @@ void clear_display(void)
     char speedbuf[4] = "  ";
     int cury, curx;
 
-    strncpy(speedbuf, speedstr + (2 * speed), 2);
-    speedbuf[2] = '\0';
+    snprintf(speedbuf, 3, "%2d", GetCWSpeed());
+
     getyx(stdscr, cury, curx);
 
     mvprintw(0, 0, "");
-    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
     mvprintw(0, 0, "                             ");
     mvprintw(0, 0, "  %s  S=%s D=%i ", mode, speedbuf, cqdelay);
     mvprintw(0, 21, headerline);
 
     if (use_rxvt == 0)
-	attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
+	attron(COLOR_PAIR(C_LOG | A_BOLD | A_STANDOUT));
     else
-	attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
+	attron(COLOR_PAIR(C_LOG | A_STANDOUT));
 
     mvaddstr(1, 0, terminal1);
     mvaddstr(2, 0, terminal2);
@@ -81,7 +80,7 @@ void clear_display(void)
     mvaddstr(5, 0, backgrnd_str);
     mvprintw(6, 0, "");
     mvaddstr(6, 0, "");
-    attron(COLOR_PAIR(COLOR_GREEN));
+    attron(COLOR_PAIR(C_HEADER));
 //    hline(ACS_HLINE, 80);
     mvaddstr(6, 0, backgrnd_str);
     mvprintw(6, (80 - strlen(whichcontest))/2 - 4, " == %s == ", whichcontest);
@@ -89,16 +88,16 @@ void clear_display(void)
     showscore();
 
     if (use_rxvt == 0)
-	attron(COLOR_PAIR(COLOR_WHITE) | A_BOLD | A_STANDOUT);
+	attron(COLOR_PAIR(C_LOG) | A_BOLD | A_STANDOUT);
     else
-	attron(COLOR_PAIR(COLOR_WHITE) | A_STANDOUT);
+	attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
     mvaddstr(7, 0, logline0);
     mvaddstr(8, 0, logline1);
     mvaddstr(9, 0, logline2);
     mvaddstr(10, 0, logline3);
     mvaddstr(11, 0, logline4);
-    attron(COLOR_PAIR(COLOR_CYAN));
+    attron(COLOR_PAIR(C_WINDOW));
     mvaddstr(12, 0, backgrnd_str);
 
     mvaddstr(12, 0, band[bandinx]);
@@ -156,14 +155,9 @@ void clear_display(void)
     if (searchflg == SEARCHWINDOW)
 	searchlog(hiscall);
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
-    else
-	attron(COLOR_PAIR(NORMCOLOR));
+    printcall();
 
-    mvaddstr(12, 29, hiscall);
-
-    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
     mvprintw(24, 0, backgrnd_str);
 
     if (use_rxvt == 0)
