@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2012           Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -9,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 	/* ------------------------------------------------------------
@@ -25,10 +26,10 @@
 #include "globalvars.h"
 #include "deleteqso.h"
 
-int delete_qso(void)
+void delete_qso(void)
 {
 
-    int x, isnote, rc;
+    int x, rc;
     int lfile;
     struct stat statbuf;
 
@@ -44,40 +45,32 @@ int delete_qso(void)
 	    sleep(2);
 	} else {
 
-	    nr_qsos--;
-	    qsos[nr_qsos][0] = '\0';
-
 	    fstat(lfile, &statbuf);
 
-	    if (statbuf.st_size > 80)
-		rc = ftruncate(lfile, statbuf.st_size - 81);
+	    if (statbuf.st_size >= LOGLINELEN)
+		rc = ftruncate(lfile, statbuf.st_size - LOGLINELEN);
 
 	    fsync(lfile);
 	    close(lfile);
 
-	}
+	    if (qsos[nr_qsos][0] != ';') {
+		band_score[bandinx]--;
+		qsonum--;
+		qsonr_to_str();
+	    }
 
-	if (logline4[0] == ';')
-	    isnote = 1;
-	else
-	    isnote = 0;
-
-	if (isnote == 0) {
-	    band_score[bandinx]--;
-	    qsonum--;
-	    qsonr_to_str();
+	    nr_qsos--;
+	    qsos[nr_qsos][0] = '\0';
 	}
 
 	scroll_log();
 
     }
 
-    attron(COLOR_PAIR(COLOR_WHITE) | A_STANDOUT);
+    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
     mvprintw(13, 29, "                            ");
 
     printcall();
 
     clear_display();
-
-    return (0);
 }
