@@ -9,12 +9,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <glib.h>
@@ -36,7 +36,7 @@ int prefix_count(void)
 	return prefix->len;
 }
 
-/* give pointer to dxcc_data struct at 'index' */
+/* give pointer to prefix struct at 'index' */
 prefix_data *prefix_by_index(int index)
 {
 	return (prefix_data *)g_ptr_array_index(prefix, index);
@@ -57,7 +57,7 @@ void prefix_add (char *pfxstr)
 	}
 	else
 	    new_prefix -> itu = last_dx -> itu;
-	    
+
 	loc = strchr(pfxstr, '(');
 	if (loc != NULL) {
 	    new_prefix -> cq = atoi(loc + 1);
@@ -65,7 +65,7 @@ void prefix_add (char *pfxstr)
 	}
 	else
 	    new_prefix -> cq = last_dx -> cq;
-	    
+
 	new_prefix -> pfx = g_strdup(pfxstr);
 	new_prefix -> dxcc_index = last_index;
 
@@ -115,7 +115,13 @@ void dxcc_add (char * dxcc_line)
 	new_dxcc -> lat = atof(split[4]);
 	new_dxcc -> lon = atof(split[5]);
 	new_dxcc -> timezone = atof(split[6]);
-	new_dxcc -> pfx = g_strdup(split[7]);
+	if (*split[7] == '*') {
+	    new_dxcc -> pfx = g_strdup(split[7]+1);
+	    new_dxcc -> starred = 1;
+	} else {
+	    new_dxcc -> pfx = g_strdup(split[7]);
+	    new_dxcc -> starred = 0;
+	}
 
 	g_ptr_array_add (dxcc, new_dxcc);
 
