@@ -1,34 +1,34 @@
 #include "tlf.h"
 #include <glib.h>
 
-extern char qsos[MAX_QSOS][82];		// array of log lines of QSOs so far; 
-					// note that not every log line needs 
-					// to be a QSO, it could also be a 
+extern char qsos[MAX_QSOS][LOGLINELEN+1];// array of log lines of QSOs so far;
+					// note that not every log line needs
+					// to be a QSO, it could also be a
 					// comment, starting with a semicolon
 extern int nr_qsos;			// number of lines in qsos[]
 
 extern char mults[MAX_MULTS][12];	// array of multipliers worked so far
 extern int multarray_nr;		// number of entries in mults[]
-extern int mult_bands[];		// bitfield indicating on which band(s) 
-					// the multiplier has been worked; 
-					// bits assigned according to 
+extern int mult_bands[];		// bitfield indicating on which band(s)
+					// the multiplier has been worked;
+					// bits assigned according to
 					// BAND160..BAND10 defined in tlf.h
-extern int multscore[NBANDS];		// number of multipliers worked per 
-					// band; index is 
+extern int multscore[NBANDS];		// number of multipliers worked per
+					// band; index is
 					// BANDINDEX_160 ... BANDINDEX_10
-					// note: until 200409111, 
-					// index was 0...5 for only 
+					// note: until 200409111,
+					// index was 0...5 for only
 					// the non-warc bands!
 
 extern char callarray[MAX_CALLS][20];	// list of all calls worked so far
 extern int callarray_nr;		// number of entries in callarray[]
-extern int call_band[MAX_CALLS];	// for each of them, a bitfield 
+extern int call_band[MAX_CALLS];	// for each of them, a bitfield
 					// indicating bands
 extern int call_country[MAX_CALLS];	// for each call, the country
 extern char call_exchange[MAX_CALLS][12]; // for each call, the last exchange
 
-extern int countries[MAX_DATALINES];	// for every country, a bitfield 
-					// indicating bands on which it has 
+extern int countries[MAX_DATALINES];	// for every country, a bitfield
+					// indicating bands on which it has
 					// been worked
 
 extern int bandinx;			// band we're currently working on
@@ -63,14 +63,15 @@ extern int w_cty;
 extern int ve_cty;
 extern int pfxmult;
 extern int minute_timer;
-
+extern int stewperry_flg;
+extern char myqra[7];
 
 // extern char logline0[81];
 // extern char logline1[81];
 // extern char logline2[81];
 // extern char logline3[81];
 // extern char logline4[];
-extern char logline_edit[5][88];
+extern char logline_edit[5][LOGLINELEN+1];
 #define logline0 logline_edit[0]
 #define logline1 logline_edit[1]
 #define logline2 logline_edit[2]
@@ -81,7 +82,7 @@ extern int stop_backgrnd_process;
 extern char band[9][4];
 extern struct tm *time_ptr;
 
-extern int inxes[NBANDS]; //  = {BAND160,BAND80,BAND40,0,BAND20,0,BAND15,0,BAND10} ;	
+extern int inxes[NBANDS]; //  = {BAND160,BAND80,BAND40,0,BAND20,0,BAND15,0,BAND10} ;
 		    // from addmult.c
 
 extern char cqzone[];
@@ -90,7 +91,7 @@ extern char continent[];
 extern char zone_export[];
 extern int itumult;
 
-GPtrArray *mults_possible;	/* growing array of possible mutlipliers */
+extern GPtrArray *mults_possible;	/* growing array of possible mutlipliers */
 extern char ssexchange[];
 extern int shownewmult;
 extern char comment[];
@@ -113,7 +114,6 @@ extern char my_rst[];
 extern char his_rst[];
 extern char section[];
 extern int wazmult;
-extern char lastcomment[];
 extern int addcallarea;
 extern int addcty;
 extern char zone_fix[];
