@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ * 		 2013 		Fred DH5FS
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -9,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "tlf.h"
@@ -37,15 +38,19 @@ int cl_send_inhibit = 0;
 char lanbuffer[255];
 struct sockaddr_in bc_address[MAXNODES];
 struct hostent *bc_hostbyname[MAXNODES];
+/* host names and UDP ports to send notifications to */
 char bc_hostaddress[MAXNODES][16];
+char bc_hostservice[MAXNODES][16] =
+	{ [0 ... MAXNODES - 1] = { [0 ... 15] = 0 } };
 char sendbuffer[256];
 int nodes = 0;
 int node;
 int send_error_limit[MAXNODES];
 //--------------------------------------
-int lan_port = 6788;
+/* default port to listen for incomming packets and to send packet to */
+char default_lan_service[16] = "6788";
+
 int lan_active = 0;
-char thisnode;
 int send_error[MAXNODES];
 int lan_mutex = 0;
 int send_packets[MAXNODES];
@@ -61,19 +66,34 @@ int landebug = 0;
 long lantime;
 long timecorr;
 int time_master;
+char thisnode = 'A'; 		/*  start with 'A' if not defined in
+				    logcfg.dat */
 
   //---------------------end lan globals --------------
 
-int lanrecv_init(void)
-{
+int resolveService(const char * service) {
+	struct servent * service_ent;
+	service_ent = getservbyname(service, "udp");
+	int port = 0;
+	if (service_ent != NULL) {
+		port = service_ent->s_port;
+	} else if (strlen(service) > 0) {
+		port = atoi(service);
+	}
+	if (port == 0) {
+		port = atoi(default_lan_service);
+	}
+	return port;
+}
 
+int lanrecv_init(void) {
     if (lan_active == 0)
 	return (1);
 
     bzero(&lan_sin, sizeof(lan_sin));
     lan_sin.sin_family = AF_INET;
     lan_sin.sin_addr.s_addr = htonl(INADDR_ANY);
-    lan_sin.sin_port = htons(lan_port);
+    lan_sin.sin_port = htons(resolveService(default_lan_service));
     lan_sin_len = sizeof(lan_sin);
 
     lan_socket_descriptor = socket(AF_INET, SOCK_DGRAM, 0);
@@ -167,11 +187,17 @@ int lan_send_init(void)
 
 	bzero(&bc_address[node], sizeof(bc_address[node]));	/* empty data structure */
 	bc_address[node].sin_family = AF_INET;
-	memcpy(&bc_address[node].sin_addr.s_addr,
-	       bc_hostbyname[node]->h_addr,
+	memcpy(&bc_address[node].sin_addr.s_addr, bc_hostbyname[node]->h_addr,
 	       sizeof(bc_address[node].sin_addr.s_addr));
 
-	bc_address[node].sin_port = htons(lan_port);
+	bc_address[node].sin_port = htons(resolveService(bc_hostservice[node]));
+
+	syslog(LOG_INFO, "open socket: to %d.%d.%d.%d:%d\n",
+		(ntohl(bc_address[node].sin_addr.s_addr) & 0xff000000) >> 24,
+		(ntohl(bc_address[node].sin_addr.s_addr) & 0x00ff0000) >> 16,
+		(ntohl(bc_address[node].sin_addr.s_addr) & 0x0000ff00) >> 8,
+		(ntohl(bc_address[node].sin_addr.s_addr) & 0x000000ff) >> 0,
+		ntohs(bc_address[node].sin_port));
 
 	bc_socket_descriptor[node] = socket(AF_INET, SOCK_DGRAM, 0);
 
@@ -303,7 +329,7 @@ int talk(void)
     send_lan_message(TLFMSG, talkline);
 
     talkline[0] = '\0';
-    attron(COLOR_PAIR(COLOR_GREEN));
+    attron(COLOR_PAIR(C_HEADER));
     mvprintw(24, 0,
 	     "                                                                               ");
     refreshp();
