@@ -9,12 +9,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
  	/* ------------------------------------------------------------
  	*        View Log using "less" function
@@ -34,11 +34,11 @@ int logview(void)
 	strcat(comstr,  "less  +G ");
 	strcat(comstr,  logfile);
 	rc=system(comstr);
-	attron(COLOR_PAIR(7) | A_STANDOUT);
+	attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 	erase();
 	refreshp();
 	clear_display();
-	attron(COLOR_PAIR(7)  |  A_STANDOUT);
+	attron(COLOR_PAIR(C_LOG)  |  A_STANDOUT);
 
 	for (j = 13 ;  j  <= 23 ; j++){
 		mvprintw(j, 0, backgrnd_str);
