@@ -2,7 +2,7 @@
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0r@eudxf.org>
  *                    2010-2011 Thomas Beierlein <tb@forth-ev.de>
- *                    2013      Ervin Hegedus <airween@gmail.com>
+ *                    2013-2014 Ervin Hegedus - HA2OS <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -115,6 +115,7 @@ float fixedmult = 0.0;
 int sectn_mult = 0;
 int dx_arrlsections = 0;
 int serial_section_mult = 0;
+int serial_or_section = 0;	/* exchange is serial OR section, like HA-DX */
 int serial_grid4_mult = 0;
 int qso_once = 0;
 int addcallarea_once = 0;
