@@ -9,23 +9,18 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <stdio.h>
-#include <stdlib.h>
-#include <curses.h>
-#include <time.h>
-#include "tlf.h"
-#include "qsonr_to_str.h"
-#include "get_time.h"
-#include "addpfx.h"
-#include "score.h"
+#ifndef _MAKELOGLINE_H
+
+#define _MAKELOGLINE_H
 
 
 void makelogline(void);
 
+#endif /* end of include guard: _MAKELOGLINE_H */
