@@ -1,9 +1,9 @@
 /*
 * Tlf - contest logging program for amateur radio operators
 * Copyright (C) 2001-2002-2003-2004 Rein Couperus <pa0rct@amsat.org>
-* 		2011-2012           Thomas Beierlein <tb@forth-ev.de>
+* 		2011-2014           Thomas Beierlein <tb@forth-ev.de>
 * 		2013 		    Fred DH5FS
-*               2013                Ervin Hegedus <airween@gmail.com>
+*               2013-2014           Ervin Hegedus - HA2OS <airween@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ void KeywordNotSupported(char *keyword);
 void ParameterNeeded(char *keyword);
 void WrongFormat(char *keyword);
 
-#define  MAX_COMMANDS 161	/* commands in list */
+#define  MAX_COMMANDS 162	/* commands in list */
 
 
 int read_logcfg(void)
@@ -230,6 +230,7 @@ int parse_logcfg(char *inputbuffer)
     extern char sc_volume[];
     extern char modem_mode[];
     extern int no_rst;
+    extern int serial_or_section;
 
 /* LZ3NY mods */
     extern int mult_side;
@@ -257,7 +258,7 @@ int parse_logcfg(char *inputbuffer)
     extern int logfrequency;
     extern int ignoredupe;
     extern char myqra[7];
-    
+
     char commands[MAX_COMMANDS][30] = {
 	"enable",		/* 0 */		/* deprecated */
 	"disable",				/* deprecated */
@@ -420,7 +421,8 @@ int parse_logcfg(char *inputbuffer)
 	"VKSPR",				/* deprecated */
 	"NO_RST",
 	"MYQRA",
-	"POWERMULT"		/* 160 */
+	"POWERMULT",		/* 160 */
+	"SERIAL_OR_SECTION"
     };
 
     char **fields;
@@ -1368,7 +1370,11 @@ int parse_logcfg(char *inputbuffer)
 	    }
 	    break;
 	}
-	    
+    case 161:{
+		 serial_or_section = 1;
+		 break;
+	    }
+
     default: {
 		KeywordNotSupported(g_strstrip(inputbuffer));
 		break;
