@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2013           Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -9,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 	/* ------------------------------------------------------------
 	 *      printcall
@@ -24,26 +25,46 @@
 #include "tlf.h"
 #include "printcall.h"
 
+extern int use_rxvt;
+
 void printcall(void)
 {
-
-    extern int use_rxvt;
     extern char hiscall[];
     extern int miniterm;
+    extern int cqmode;
+    extern int cwstart;
 
     int currentterm;
+    attr_t attrib = A_STANDOUT;
 
     currentterm = miniterm;
     miniterm = 0;
 
     if (use_rxvt == 0)
-	attron(COLOR_PAIR(COLOR_BLUE) | A_STANDOUT | A_BOLD);
-    else
-	attron(COLOR_PAIR(COLOR_BLUE) | A_STANDOUT);
+	attrib |= A_BOLD;
+
+    attron(COLOR_PAIR(C_INPUT) | attrib);
 
     mvprintw(12, 29, "            ");
     mvprintw(12, 29, hiscall);
+    if ((cqmode == CQ) && (cwstart != 0))
+    	mvchgat(12, 29 + cwstart, 12 - cwstart,
+		attrib | A_UNDERLINE, C_INPUT, NULL);
     refreshp();
 
     miniterm = currentterm;
 }
+
+/** highlight the first n characters of the call input field
+ *
+ * \parm n number of characters to highlight
+ */
+void highlightCall(unsigned int n) {
+    attr_t attrib = A_NORMAL; 	/* use NORMAL here as normal display
+				   uses STANDOUT */
+
+    if (use_rxvt == 0)
+	attrib |= A_BOLD;
+
+    mvchgat(12, 29, n, attrib, C_INPUT, NULL);
+}
