@@ -1,6 +1,8 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2013           Ervin Hegedus <airween@gmail.com>
+ *               2013-2014      Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -9,19 +11,27 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+
 	/* ------------------------------------------------------------
 	 *     score
 	 *
 	 *--------------------------------------------------------------*/
 
+#include "qrb.h"
+#include "locator2longlat.h"
 #include "score.h"
+#include "tlf.h"
+#include "getctydata.h"
+#include "focm.h"
+#include <math.h>
+
 
 int calc_continent(int zone);
 
@@ -93,17 +103,16 @@ int score()
 {
 
     extern int dupe;
-    extern int points;
     extern int one_point;
     extern int two_point;
     extern int three_point;
     extern int band_score[9];
     extern int bandinx;
+    extern int focm;
     extern int wpx;
     extern int pfxmult;
     extern int countrynr;
     extern int mycountrynr;
-    extern int total;
     extern char continent[];
     extern char mycontinent[];
     extern char comment[];
@@ -118,6 +127,9 @@ int score()
     extern int lowband_point_mult;
     extern int portable_x2;
     extern char hiscall[];
+    extern char myqra[7];
+    extern char call[];
+    extern int stewperry_flg;
 
 /* LZ3NY mods */
 
@@ -127,6 +139,7 @@ int score()
     extern int dx_cont_points;
     extern int countrylist_only;
 
+    int points;
     int is_mult = 0;
 /* end LZ3NY mods */
 
@@ -136,7 +149,7 @@ int score()
     if (dupe == ISDUPE) {
 	points = 0;
 	dupe = NODUPE;
-	return (0);
+	return points;
     }
 
     band_score[bandinx]++;	/* qso's per band  */
@@ -145,51 +158,50 @@ int score()
 	&& ((countrynr == w_cty) || (countrynr == ve_cty)))
 	band_score[bandinx]--;
 
+    if (focm == 1) {
+	points = foc_score(hiscall);
+
+	return points;
+    }
+
     if (wpx == 1 && pfxmult == 0) {
 	if (countrynr == mycountrynr) {
 	    points = 1;
-	    total = total + 1;
 
-	    return (0);
+	    return points;
 	}
 
 	if ((strcmp(continent, mycontinent) == 0)
 	    && (bandinx > BANDINDEX_30)) {
 	    if (strstr(mycontinent, "NA") != NULL) {
 		points = 2;
-		total = total + 2;
 	    } else {
 		points = 1;
-		total = total + 1;
 	    }
 
-	    return (0);
+	    return points;
 	}
 
 	if ((strcmp(continent, mycontinent) == 0)
 	    && (bandinx < BANDINDEX_30)) {
 	    if (strstr(mycontinent, "NA") != NULL) {
 		points = 4;
-		total = total + 4;
 	    } else {
 		points = 2;
-		total = total + 2;
 	    }
-	    return (0);
+	    return points;
 	}
 	if ((strcmp(continent, mycontinent) != 0)
 	    && (bandinx > BANDINDEX_30)) {
 	    points = 3;
-	    total = total + 3;
 
-	    return (0);
+	    return points;
 	}
 	if ((strcmp(continent, mycontinent) != 0)
 	    && (bandinx < BANDINDEX_30)) {
 	    points = 6;
-	    total = total + 6;
 
-	    return (0);
+	    return points;
 	}
     }				// end wpx
 
@@ -202,25 +214,22 @@ int score()
 
 	if ((countrynr == mycountrynr)) {
 	    points = 0;
-	    total = total + 0;
-	    return (0);
+
+	    return points;
 	}
 
 	if (strcmp(continent, mycontinent) == 0) {
 	    if (strstr(mycontinent, "NA") != NULL) {
 		points = 2;
-		total = total + 2;
 	    } else {
 		points = 1;
-		total = total + 1;
 	    }
 
-	    return (0);
+	    return points;
 	} else {
 	    points = 3;
-	    total = total + 3;
 
-	    return (0);
+	    return points;
 	}
 
     }
@@ -230,32 +239,27 @@ int score()
 
 	if (trxmode == SSBMODE) {
 	    points = 1;
-	    total = total + 1;
 	} else {
 	    points = 2;
-	    total = total + 2;
 
 	}
-	return (0);
+	return points;
 
     }				// end arrl_fd
 
     if (one_point == 1) {
 	points = 1;
-	total++;
 
-	return (0);
+	return points;
     }
     if (two_point == 1) {
 	points = 2;
-	total = total + 2;
-	return (0);
+	return points;
     }
     if (three_point == 1) {
 	points = 3;
-	total = total + 3;
 
-	return (0);
+	return points;
     }
 
     if (arrldx_usa == 1) {
@@ -265,10 +269,27 @@ int score()
 
 	} else {
 	    points = 3;
-	    total = total + 3;
 	}
 
-	return (0);
+	return points;
+    }
+
+    if (stewperry_flg == 1) {
+
+	double s1long, s1lat, s2long, s2lat, distance, azimuth;
+
+	points = 0;
+
+	if (strlen(comment) > 3) {
+	    locator2longlat(&s1long, &s1lat, comment);
+	    locator2longlat(&s2long, &s2lat, myqra);
+
+	    qrb(s1long, s1lat, s2long, s2lat, &distance, &azimuth);
+
+	    points = ceil(distance/500.0);
+	}
+
+	return points;
     }
 
     /* end arrldx_usa */
@@ -335,27 +356,21 @@ int score()
 	}
     }
 
-    /* The Result of all ABOVE */
-    total = total + points;
-
-    return (0);
+    return points;
 }
 
+
 /* -----------------------------------------------------------------*/
-int score2(void)
+int score2(char *line)
 {
 
-    extern char lan_logline[];
-    extern int total;
-
-    total = total + atoi(lan_logline + 75);
-
-    return (0);
+    return atoi(line + 75);
 }
 
- /* ----------------------------------------------------------------- */
+
+/* ----------------------------------------------------------------- */
 int calc_continent(int zone)
-{				// calculates continent from zone and sets continent
+{			// calculates continent from zone and sets continent
 
     extern char continent[];
 
@@ -386,3 +401,4 @@ int calc_continent(int zone)
     }
     return (0);
 }
+
