@@ -9,13 +9,17 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#ifndef SENDBUF_H
+
+#define SENDBUF_H
+
 #include<stdlib.h>
 #include<string.h>
 #include <ctype.h>
@@ -25,6 +29,9 @@
 #include "tlf.h"
 #include "displayit.h"
 
+extern char buffer[];
 
 void sendbuf(void);
+void sendmessage(char *msg);
 
+#endif /*  SENDBUF_H */
