@@ -178,8 +178,8 @@ int init_tlf_rig(void)
     rigfreq = 0.0;
 
     retcode = rig_get_vfo(my_rig, &vfo); 	/* initialize RIG_VFO_CURR */
-    if (retcode == RIG_OK)
-	rig_get_freq(my_rig, RIG_VFO_CURR, &rigfreq);
+    if (retcode == RIG_OK || retcode == -RIG_ENIMPL || retcode == -RIG_ENAVAIL)
+	retcode = rig_get_freq(my_rig, RIG_VFO_CURR, &rigfreq);
 
     if (retcode != RIG_OK) {
 	showmsg("Problem with rig link!");
