@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2013           Ervin Hegedus <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -9,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
     /* ------------------------------------------------------------
      *      Set contest parameters
@@ -22,10 +23,12 @@
      *--------------------------------------------------------------*/
 
 #include "setcontest.h"
+#include "focm.h"
 
 int setcontest(void)
 {
 
+    extern int focm;
     extern int wpx;
     extern int pfxmult;
     extern int cqww;
@@ -37,6 +40,7 @@ int setcontest(void)
     extern int arrlss;
     extern int multlist;
     extern int pacc_pa_flg;
+    extern int stewperry_flg;
     extern int universal;
     extern int other_flg;
     extern int exchange_serial;
@@ -83,6 +87,7 @@ int setcontest(void)
     sprint = 0;
     arrldx_usa = 0;
     pacc_pa_flg = 0;
+    focm = 0;
     universal = 0;
     contest = 0;
     showscore_flag = 0;
@@ -188,6 +193,17 @@ int setcontest(void)
 	ua9_cty = getctydata(ua9call);
     }
 
+    if (strcmp(whichcontest, "stewperry") == 0) {
+	stewperry_flg = 1;
+	contest = 1;
+	showscore_flag = 1;
+	searchflg = 1;
+    }
+
+    if (strcmp(whichcontest, "focmarathon") == 0) {
+	foc_init();
+    }
+
     if (strcmp(whichcontest, "other") == 0) {
 	other_flg = 1;
 	one_point = 1;
