@@ -9,12 +9,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 	/* ------------------------------------------------------------
 	 *
@@ -24,7 +24,7 @@
 
 /** Show infos for selected country on bottom of screen
  *
- * Prepares info string for the selected country and shows it on the 
+ * Prepares info string for the selected country and shows it on the
  * bottom line of the screen.
  *
  * /param x  Country number
@@ -43,7 +43,7 @@ int showinfo(int x)
     extern double bearing;
     extern double range;
     extern int timeoffset;
-    extern int timecorr;
+    extern long timecorr;
     extern char itustr[];
     extern int mycountrynr;
 
@@ -92,7 +92,7 @@ int showinfo(int x)
     contstr[2] = '\0';
 
     getyx(stdscr, cury, curx);
-    attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
     mvprintw(24, 0, " %s  %s             ", pxstr, countrystr);
 
@@ -101,12 +101,12 @@ int showinfo(int x)
 	 contstr, zonestr);
 
     if (x != 0 && x != mycountrynr) {
-	qrb();
+	qrb_();
 	mvprintw(24, 35, "%.0f km/%.0f deg ", range, bearing);
     }
 
     mvprintw(24, 64, "  DX time: %s", timebuff);
- 
+
     if (use_rxvt == 0)
 	attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
     else
