@@ -9,12 +9,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 	/* ------------------------------------------------------------
 	 *   show prefix map
@@ -23,6 +23,7 @@
 
 #include "showpxmap.h"
 #include "dxcc.h"
+#include "focm.h"
 
 int show_mults(void)
 {
@@ -31,6 +32,8 @@ int show_mults(void)
     extern int bandinx;
     extern int cqww;
 
+    extern int focm;
+
     int i, j, k, l, bandmask = 0;
     static char prefix[5];
     static char zonecmp[3] = "";
@@ -38,6 +41,11 @@ int show_mults(void)
 
     int iMax = dxcc_count();
 
+    if (focm == 1) {
+	foc_show_cty();
+	return 0;
+    }
+
     if (cqww == 1) {
 
 	mvprintw(12, 29, "E,A,F,N,S,O");
@@ -67,16 +75,20 @@ int show_mults(void)
 	    else
 		strcat(zonecmp, "EU");
 
-	    attron(COLOR_PAIR(7) | A_STANDOUT);
+	    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+
+	    for (l = 1; l < 6; l++)
+		mvprintw(l, 0,
+			 "                                                                                ");
 
 	    i = 0;
 
-	    for (k = 1; k <= 5; k++) {
+	    for (k = 1; k < 6; k++) {
 
 		for (j = 0; j <= 19; j++) {
 
-		    while ((i < iMax) && 
-			((strncmp(dxcc_by_index(i) -> continent, zonecmp, 2)) 
+		    while ((i < iMax) &&
+			((strncmp(dxcc_by_index(i) -> continent, zonecmp, 2))
 				!= 0)) {
 			i++;
 		    }
@@ -117,17 +129,17 @@ int show_mults(void)
 			strncat(prefix, "     ", 4 - strlen(prefix));
 
 			if (use_rxvt == 0)
-			    attron(COLOR_PAIR(4) | A_BOLD);
+			    attron(COLOR_PAIR(C_INPUT) | A_BOLD);
 			else
-			    attron(COLOR_PAIR(4));
+			    attron(COLOR_PAIR(C_INPUT));
 
-			mvprintw(k + 1, j * 4, prefix);
+			mvprintw(k, j * 4, prefix);
 			refreshp();
 			i++;
 
 		    } else {
 
-			mvprintw(k + 1, j * 4, "    ");
+			mvprintw(k, j * 4, "    ");
 			refreshp();
 			i++;
 
@@ -141,13 +153,14 @@ int show_mults(void)
 
 	    ch = getchar();
 
-	    attron(COLOR_PAIR(7) | A_STANDOUT);
+	    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
-	    for (l = 1; l <= 6; l++)
-		mvprintw(l, 0,
-			 "                                                                                ");
 
 	}			// end while
+
+	for (l = 1; l < 6; l++)
+	    mvprintw(l, 0,
+		     "                                                                                ");
     } else
 
 	multiplierinfo();
