@@ -16,7 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
- // splitscreen.h
+
+#ifndef SPLITSCREEN_H
+#define SPLITSCREEN_H
 
 #include <sys/types.h>
 #include <curses.h>
@@ -80,3 +82,5 @@ int cleanup_telnet (void);
 int packet(void);
 int receive_packet(void);
 int send_cluster(void);
+
+#endif /* end of include guard: SPLITSCREEN_H */
