@@ -10,12 +10,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 	/* ------------------------------------------------------------
 	 *
@@ -32,7 +32,7 @@ void time_update(void)
     extern char qsonrstr[];
     extern int bandinx;
     extern int this_second;
-    extern long system_secs;
+    extern int system_secs;
     extern int miniterm;
 
     char time_buf[11];
@@ -74,16 +74,16 @@ void time_update(void)
 
 	    clusterinfo(time_buf);	/* update cluster info (2 seconds) */
 
-	    attron(COLOR_PAIR(7) | A_STANDOUT);
+	    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
 	    mvprintw(7, 0, logline0);
 	    mvprintw(8, 0, logline1);
 	    mvprintw(9, 0, logline2);
 	    mvprintw(10, 0, logline3);
 	    mvprintw(11, 0, logline4);
-	    mvprintw(13, 0, 
+	    mvprintw(13, 0,
 		    "                                                                    ");
-	    attron(COLOR_PAIR(COLOR_CYAN));
+	    attron(COLOR_PAIR(C_WINDOW));
 	    mvprintw(12, 23, qsonrstr);
 	    printcall();
 
